@@ -1,6 +1,6 @@
 package ZMQ::FFI::Util;
 {
-  $ZMQ::FFI::Util::VERSION = '0.10';
+  $ZMQ::FFI::Util::VERSION = '0.11';
 }
 
 # ABSTRACT: zmq convenience functions
@@ -20,13 +20,23 @@ use Sub::Exporter -setup => {
 };
 
 sub zmq_soname {
-    # try to find a soname available on this system
+    my %args = @_;
 
-    # .so symlink conventions are linker_name => soname => real_name
+    my $die = $args{die};
+
+    # Try to find a soname available on this system
+    #
+    # Linux .so symlink conventions are linker_name => soname => real_name
     # e.g. libzmq.so => libzmq.so.X => libzmq.so.X.Y.Z
-    # Unfortunately not all distros follow this convention (Ubuntu).
-    # So first we'll try the linker_name, then the sonames, and then give up
-    my @sonames = qw(libzmq.so libzmq.so.3 libzmq.so.1);
+    # Unfortunately not all distros follow this convention (Ubuntu). So first
+    # we'll try the linker_name, then the sonames.
+    #
+    # If Linux extensions fail also try platform specific
+    # extensions (e.g. OS X) before giving up.
+    my @sonames = qw(
+        libzmq.so    libzmq.so.3    libzmq.so.1
+        libzmq.dylib libzmq.3.dylib libzmq.1.dylib
+    );
 
     my $soname;
     FIND_SONAME:
@@ -49,6 +59,13 @@ sub zmq_soname {
         last FIND_SONAME if $soname;
     }
 
+    if ( !$soname && $die ) {
+        croak
+            qq(Could not load libzmq, tried:\n),
+            join(', ', @sonames),"\n",
+            q(Is libzmq on your ld path?);
+    }
+
     return $soname;
 }
 
@@ -88,7 +105,7 @@ ZMQ::FFI::Util - zmq convenience functions
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
