@@ -1,6 +1,6 @@
 package ZMQ::FFI::ZMQ3::Socket;
 {
-  $ZMQ::FFI::ZMQ3::Socket::VERSION = '0.10';
+  $ZMQ::FFI::ZMQ3::Socket::VERSION = '0.11';
 }
 
 use Moo;
@@ -10,9 +10,7 @@ use FFI::Raw;
 
 extends q(ZMQ::FFI::SocketBase);
 
-with q(ZMQ::FFI::SocketRole);
-
-has zmq3_ffi => (
+has _zmq3_ffi => (
     is      => 'ro',
     lazy    => 1,
     builder => '_init_zmq3_ffi',
@@ -31,7 +29,7 @@ sub send {
 
     $self->check_error(
         'zmq_send',
-        $self->zmq3_ffi->{zmq_send}->(
+        $self->_zmq3_ffi->{zmq_send}->(
             $self->_socket, $msg, $length, $flags
         )
     );
@@ -42,7 +40,7 @@ sub recv {
 
     $flags //= 0;
 
-    my $ffi = $self->ffi;
+    my $ffi = $self->_ffi;
 
     my $msg_ptr = FFI::Raw::memptr(40); # large enough to hold zmq_msg_t
 
@@ -52,7 +50,7 @@ sub recv {
     );
 
     my $msg_size =
-        $self->zmq3_ffi->{zmq_msg_recv}->($msg_ptr, $self->_socket, $flags);
+        $self->_zmq3_ffi->{zmq_msg_recv}->($msg_ptr, $self->_socket, $flags);
 
     $self->check_error('zmq_msg_recv', $msg_size);
 
@@ -111,7 +109,7 @@ ZMQ::FFI::ZMQ3::Socket
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHOR
 
